============
z3c.password
============


.. image:: https://github.com/zopefoundation/z3c.password/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/zopefoundation/z3c.password/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/z3c.password/badge.svg?branch=master
   :target: https://coveralls.io/github/zopefoundation/z3c.password?branch=master

.. image:: https://img.shields.io/pypi/v/z3c.password.svg
    :target: https://pypi.python.org/pypi/z3c.password

.. image:: https://img.shields.io/pypi/pyversions/z3c.password.svg
    :target: https://pypi.python.org/pypi/z3c.password/

This package provides an API and implementation of a password generation and
verification utility. A high-security implementation is provided that is
suitable for banks and other high-security institutions. The package also
offers a field and a property for those fields.
